@@ -1,10 +1,10 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2006  Alexandru Csete.
+    Copyright (C)  2001-2004  Alexandru Csete.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
     http://sourceforge.net/projects/groundstation/
@@ -33,4 +33,13 @@
 #define GRIG_CONFIG_H 1
 
 
+#define GRIG_CFG_VER     1
+#define GRIG_RIG_CFG_VER 1
+#define GRIG_ROT_CFG_VER 1
+#define GRIG_MEM_CFG_VER 1
+
+
+gint grig_config_check (void);
+
+
 #endif
