@@ -1,10 +1,9 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2006  Alexandru Csete.
+    Copyright (C)  2001-2007  Alexandru Csete.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
     http://sourceforge.net/projects/groundstation/
@@ -32,6 +31,18 @@
 #ifndef GRIG_GTK_WORKAROUNDS_H
 #define GRIG_GTK_WORKAROUNDS_H 1
 
-void grig_set_combo_tooltips (GtkWidget *combo, gpointer text);
+
+
+GtkWidget *grig_hpixmap_button (const gchar *file,
+                                const gchar *text,
+                                const gchar *tooltip);
+
+GtkWidget *grig_vpixmap_button (const gchar *file,
+                                const gchar *text,
+                                const gchar *tooltip);
+
+GtkWidget *grig_hstock_button  (const gchar *stock_id,
+                                const gchar *text,
+                                const gchar *tooltip);
 
 #endif
