@@ -1,10 +1,10 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2006  Alexandru Csete.
+    Copyright (C)  2001-2007  Alexandru Csete.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
     http://sourceforge.net/projects/groundstation/
@@ -36,6 +36,7 @@
 #include "rig-gui-message-window.h"
 #include "rig-gui-rx.h"
 #include "rig-gui-tx.h"
+#include "rig-gui-func.h"
 #include "rig-state.h"
 #include "grig-debug.h"
 
@@ -50,6 +51,7 @@ static void  grig_menu_app_exit        (GtkWidget *, gpointer);
 static void  grig_menu_set_debug_level (GtkRadioAction *, gpointer);
 static void  rx_window_cb (GtkToggleAction *toggleaction, gpointer data);
 static void  tx_window_cb (GtkToggleAction *toggleaction, gpointer data);
+static void  func_window_cb (GtkToggleAction *toggleaction, gpointer data);
 
 
 /** \brief Regular menu items. */
@@ -80,7 +82,7 @@ static GtkActionEntry entries[] = {
 	{ "Spectrum", GTK_STOCK_JUMP_TO, N_("S_pectrum Scope"), NULL, N_("Show the spectrum scope"), NULL },
 
 	/* HelpMenu */
-	{ "About", GTK_STOCK_ABOUT, N_("_About Grig"), NULL, N_("Shouw about dialog"), G_CALLBACK (grig_about_run) },
+	{ "About", GTK_STOCK_ABOUT, N_("_About Grig"), NULL, N_("Show about dialog"), G_CALLBACK (grig_about_run) },
 };
 
 
@@ -100,7 +102,7 @@ static GtkToggleActionEntry toggle_entries[] =
 	{ "LevelsRX", NULL, N_("_RX Level Controls"), NULL, N_("Show receiver level controls"), G_CALLBACK (rx_window_cb) },
 	{ "LevelsTX", NULL, N_("_TX Level Controls"), NULL, N_("Show transmitter level controls"), G_CALLBACK (tx_window_cb) },
 	{ "Tones", NULL, N_("_DCS/CTCSS"), NULL, N_("Show DCS and CTCSS controls"), NULL },
-	{ "Func", GTK_STOCK_DIALOG_INFO, N_("_Special Functions"), NULL, N_("Radio specific functions"), NULL },
+	{ "Func", GTK_STOCK_DIALOG_INFO, N_("_Special Functions"), NULL, N_("Radio specific functions"), G_CALLBACK (func_window_cb) },
 };
 
 
@@ -135,8 +137,8 @@ static const char *menu_desc =
 "       <menuitem action='LevelsTX'/>"
 "       <separator/>"
 /* "       <menuitem action='Tones'/>" */
-/* "       <menuitem action='Func'/>" */
-/* "       <separator/>" */
+"       <menuitem action='Func'/>"
+"       <separator/>"
 "       <menuitem action='MsgWin'/>"
 "    </menu>"
 /* "    <menu action='ToolsMenu'>" */
@@ -167,9 +169,30 @@ grig_menubar_create ()
 	GtkActionGroup *actgrp;
 	GtkAccelGroup  *accgrp;
 	GError         *error;
+	gint           i;
 
 	/* create action group */
 	actgrp = gtk_action_group_new ("MenuActions");
+	/* i18n */
+	for (i=0; i<G_N_ELEMENTS (entries); i++) {
+		if (entries[i].label)
+			entries[i].label = _(entries[i].label);
+		if (entries[i].tooltip)
+			entries[i].tooltip = _(entries[i].tooltip);
+	}
+	for (i=0; i<G_N_ELEMENTS (radio_entries); i++) {
+		if (radio_entries[i].label)
+			radio_entries[i].label = _(radio_entries[i].label);
+		if (radio_entries[i].tooltip)
+			radio_entries[i].tooltip = _(radio_entries[i].tooltip);
+	}
+	for (i=0; i<G_N_ELEMENTS (toggle_entries); i++) {
+		if (toggle_entries[i].label)
+			toggle_entries[i].label = _(toggle_entries[i].label);
+		if (toggle_entries[i].tooltip)
+			toggle_entries[i].tooltip = _(toggle_entries[i].tooltip);
+	}
+
 	gtk_action_group_add_actions (actgrp, entries, G_N_ELEMENTS (entries), NULL);
 
 	/* debug level radio group */
@@ -241,7 +264,7 @@ grig_menu_set_debug_level (GtkRadioAction *action, gpointer data)
 
 /** \brief Show/hide RX controls
  *
- * This function is called when the user selects the "RX controls" menut item.
+ * This function is called when the user selects the "RX controls" menu item.
  * Depending on the state of the item (on/off) we have to either open or close
  * the CW controls window
  */
@@ -260,7 +283,7 @@ rx_window_cb (GtkToggleAction *toggleaction, gpointer user_data)
 
 /** \brief Show/hide TX controls
  *
- * This function is called when the user selects the "TX controls" menut item.
+ * This function is called when the user selects the "TX controls" menu item.
  * Depending on the state of the item (on/off) we have to either open or close
  * the CW controls window
  */
@@ -277,6 +300,25 @@ tx_window_cb (GtkToggleAction *toggleaction, gpointer user_data)
 }
 
 
+/** \brief Show/hide FUNC controls
+ *
+ * This function is called when the user selects the "Func controls" menu item.
+ * Depending on the state of the item (on/off) we have to either open or close
+ * the CW controls window
+ */
+static void
+func_window_cb (GtkToggleAction *toggleaction, gpointer user_data)
+{
+
+	if (gtk_toggle_action_get_active (toggleaction)) {
+		rig_gui_func_create ();
+	}
+	else {
+		rig_gui_func_close ();
+	}
+}
+
+
 /** \bried Force TX menu item.
  *
  * This function can be used to force the TX controls menu item to
@@ -311,3 +353,20 @@ grig_menubar_force_rx_item (gboolean val)
 		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), val);
 }
 
+/** \bried Force FUNC menu item.
+ *
+ * This function can be used to force the FUNC controls menu item to
+ * TRUE or FALSE. This is useful when the FUNC controls window is closed
+ * without any menu action
+ */
+void
+grig_menubar_force_func_item (gboolean val)
+{
+	GtkWidget *item = NULL;
+
+	item = gtk_ui_manager_get_widget (uimgr, "/GrigMenu/ViewMenu/Func");
+
+	if (item != NULL)
+		gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), val);
+}
+
