@@ -178,13 +178,14 @@ main (int argc, char *argv[])
 	g_free (fname);
 
 
+#if !GLIB_CHECK_VERSION(2,32,0)
 	/* initialize threads; according to glib docs, this call will terminate
 	   the program if threads are not supported... then why doesn''t it work
 	   on FreeBSD?
 	*/
 	if (!g_thread_supported ())
 		g_thread_init (NULL);
-
+#endif
 
 
 	/* decode command line arguments; this part of the code only sets the
@@ -665,7 +666,6 @@ static void
 grig_list_rigs ()
 {
 	GArray *array;
-	gint status;
 	gint i;
 	grig_rig_info_t *info;
 
@@ -678,7 +678,7 @@ grig_list_rigs ()
 	rig_load_all_backends();
 
 	/* fill list using rig_list_foreach */
-	status = rig_list_foreach (grig_list_add, (void *) array);
+	rig_list_foreach (grig_list_add, (void *) array);
 
 	/* sort the array */
 	g_array_sort (array, grig_list_compare);
