@@ -1,10 +1,10 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
     Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2006  Alexandru Csete.
+    Copyright (C)  2001-2007  Alexandru Csete.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+    Authors: Alexandru Csete <oz9aec@gmail.com>
 
     Comments, questions and bugreports should be submitted via
     http://sourceforge.net/projects/groundstation/
@@ -242,8 +242,8 @@ rig_daemon_check_rit      (RIG               *myrig,
 	shortfreq_t       sfreq;                   /* current RIT setting */
 
 	/* checkfor RIT availability */
-	has_get->rit = (myrig->caps->get_rit != NULL) ? TRUE : FALSE;
-	has_set->rit = (myrig->caps->set_rit != NULL) ? TRUE : FALSE;
+	has_get->rit = (myrig->caps->get_rit != NULL && myrig->state.max_rit) ? TRUE : FALSE;
+	has_set->rit = (myrig->caps->set_rit != NULL && myrig->state.max_rit) ? TRUE : FALSE;
 
 	if (has_get->rit) {
 		/* try to get RIT setting */
@@ -261,7 +261,7 @@ rig_daemon_check_rit      (RIG               *myrig,
 
 	if (has_get->rit || has_set->rit) {
 		/* get RIT range and tuning step */
-		get->ritmax = myrig->caps->max_rit;
+		get->ritmax = myrig->state.max_rit;
 		get->ritstep = s_Hz(10);
 
 	}
@@ -298,8 +298,8 @@ rig_daemon_check_xit      (RIG               *myrig,
 	shortfreq_t       sfreq;                   /* current XIT setting */
 
 	/* checkfor XIT availability */
-	has_get->xit = (myrig->caps->get_xit != NULL) ? TRUE : FALSE;
-	has_set->xit = (myrig->caps->set_xit != NULL) ? TRUE : FALSE;
+	has_get->xit = (myrig->caps->get_xit != NULL && myrig->state.max_xit) ? TRUE : FALSE;
+	has_set->xit = (myrig->caps->set_xit != NULL && myrig->state.max_xit) ? TRUE : FALSE;
 
 	if (has_get->xit) {
 		/* try to get RIT setting */
@@ -317,7 +317,7 @@ rig_daemon_check_xit      (RIG               *myrig,
 
 	if (has_get->xit || has_set->xit) {
 		/* get XIT range and tuning step */
-		get->xitmax = myrig->caps->max_xit;
+		get->xitmax = myrig->state.max_xit;
 		get->xitstep = s_Hz(10);
 	}
 	else {
@@ -389,6 +389,9 @@ rig_daemon_check_mode     (RIG               *myrig,
 			/* store modes */
 			get->allmodes |= myrig->state.rx_range_list[i].modes;
 
+			/* store antennas */
+			get->allantennas |= myrig->state.rx_range_list[i].ant;
+
 			/* if we have not yet found a mode      AND
 			   this list is good for current mode   AND
 			   the current frequency is within this range
@@ -654,7 +657,7 @@ rig_daemon_check_level     (RIG               *myrig,
 		retcode = rig_get_level (myrig, RIG_VFO_CURR, RIG_LEVEL_IF, &val);
 		if (retcode == RIG_OK) {
 			get->ifs = val.i;
-			get->ifsmax = myrig->caps->max_ifshift;
+			get->ifsmax = myrig->state.max_ifshift;
 			get->ifsstep = s_Hz(10);
 		}
 		else {
@@ -881,8 +884,8 @@ rig_daemon_check_level     (RIG               *myrig,
 	if (has_get->att || has_set->att) {
 		int i = 0;
 
-		while ((i < MAXDBLSTSIZ) && (myrig->caps->attenuator[i] != 0)) {
-			rig_data_set_att_data (i, myrig->caps->attenuator[i]);
+		while ((i < MAXDBLSTSIZ) && (myrig->state.attenuator[i] != 0)) {
+			rig_data_set_att_data (i, myrig->state.attenuator[i]);
 			i++;
 		}
 		
@@ -892,8 +895,8 @@ rig_daemon_check_level     (RIG               *myrig,
 	if (has_get->preamp || has_set->preamp) {
 		int i = 0;
 
-		while ((i < MAXDBLSTSIZ) && (myrig->caps->preamp[i] != 0)) {
-			rig_data_set_preamp_data (i, myrig->caps->preamp[i]);
+		while ((i < MAXDBLSTSIZ) && (myrig->state.preamp[i] != 0)) {
+			rig_data_set_preamp_data (i, myrig->state.preamp[i]);
 			i++;
 		}
 	}
@@ -923,6 +926,8 @@ rig_daemon_check_func     (RIG               *myrig,
 	int               retcode;                 /* Hamlib status code */
 	setting_t         hasfunc;                 /* available func settings */
 	int               val;                     /* generic value */
+	int               i;                       /* setting index */
+	setting_t         func;                    /* setting iterated */
 
 
 	/* get available read funcs
@@ -932,6 +937,11 @@ rig_daemon_check_func     (RIG               *myrig,
 	/* unmask bits */
 	has_get->lock    = ((hasfunc & RIG_FUNC_LOCK) ? 1 : 0);
 
+	for (i=0; i < RIG_SETTING_MAX; i++) {
+		func = rig_idx2setting(i);
+		has_get->funcs[i]  = rig_has_get_func(myrig, func) ? 1 : 0;
+	}
+
 	/* read values */
 	if (has_get->lock) {
 		retcode = rig_get_func (myrig, RIG_VFO_CURR, RIG_FUNC_LOCK, &val);
@@ -946,6 +956,22 @@ rig_daemon_check_func     (RIG               *myrig,
 		}
 	}
 
+	for (i=0; i < RIG_SETTING_MAX; i++) {
+		func = rig_idx2setting(i);
+		if (has_get->funcs[i]) {
+			retcode = rig_get_func (myrig, RIG_VFO_CURR, func, &val);
+			if (retcode == RIG_OK) {
+				get->funcs[i] = val;
+			}
+			else {
+				/* send an error report */
+				grig_debug_local (RIG_DEBUG_ERR,
+						  _("%s: Could not get %s status"),
+						  __FUNCTION__,
+						  rig_strfunc(func));
+			}
+		}
+	}
 
 	/* get available write funcs */
 	hasfunc = rig_has_set_func (myrig, GRIG_FUNC_WR);
@@ -956,4 +982,8 @@ rig_daemon_check_func     (RIG               *myrig,
 	*/
 	has_set->lock  = ((hasfunc & RIG_FUNC_LOCK) ? 1 : 0);
 
+	for (i=0; i < RIG_SETTING_MAX; i++) {
+		func = rig_idx2setting(i);
+		has_set->funcs[i]  = rig_has_set_func(myrig, func) ? 1 : 0;
+	}
 }
