@@ -1,34 +1,34 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
-    Grig:  Gtk+ user interface for the Hamradio Control Libraries.
+  Grig:  Gtk+ user interface for the Hamradio Control Libraries.
 
-    Copyright (C)  2001-2006  Alexandru Csete.
+  Copyright (C)  2001-2007  Alexandru Csete.
 
-    Authors: Alexandru Csete <csete@users.sourceforge.net>
+  Authors: Alexandru Csete <oz9aec@gmail.com>
 
-    Comments, questions and bugreports should be submitted via
-    http://sourceforge.net/projects/groundstation/
-    More details can be found at the project home page:
+  Comments, questions and bugreports should be submitted via
+  http://sourceforge.net/projects/groundstation/
+  More details can be found at the project home page:
 
-            http://groundstation.sourceforge.net/
+  http://groundstation.sourceforge.net/
  
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation; either version 2 of the License, or
+  (at your option) any later version.
   
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
   
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, visit http://www.fsf.org/
+  You should have received a copy of the GNU General Public License
+  along with this program; if not, visit http://www.fsf.org/
 */
 
 /**** FIXME: Add support for double-reading of some values. For example,
-             ALC and RF power should support both meter reading as well
-             as setting
+      ALC and RF power should support both meter reading as well
+      as setting
 */
 
 
@@ -87,6 +87,7 @@ typedef struct {
 	int              att;      /*!< Attenuator. */
 	int              preamp;   /*!< Pre-amplifier. */
 	split_t          split;    /*!< Spit ON/OFF. */
+	ant_t            antenna;  /*!< Antenna. */
 
 	/* R/W levels */
 	float           afg;       /*!< AF gain */
@@ -114,6 +115,9 @@ typedef struct {
 	float           swr;       /*!< SWR. */
 	float           alc;       /*!< ALC. */
 
+	/* func's */
+	int             funcs[RIG_SETTING_MAX]; /*!< Func's */
+
 	/* write only fields */
 	int             vfo_op_toggle;  /*!< Toggle VFO */
 	int             vfo_op_copy;    /*!< Copy VFO */
@@ -130,6 +134,7 @@ typedef struct {
 	shortfreq_t     ifsmax;    /*!< Absolute max IF shift. */
 	shortfreq_t     ifsstep;   /*!< Smallest IF shift step. */
 	int             allmodes;  /*!< Bit field of all supported modes. */
+	int             allantennas;/*!< Bit field of all supported antennas. */
 } grig_settings_t;
 
 
@@ -151,6 +156,7 @@ typedef struct {
 	int         vfo_op_toggle;
 	int         vfo_op_copy;
 	int         vfo_op_xchg;
+	int         antenna;
 
 	/* R/W levels */
 	int         afg;       /*!< AF gain */
@@ -177,22 +183,24 @@ typedef struct {
 	int         strength;
 	int         swr;
 	int         alc;
+
+	int         funcs[RIG_SETTING_MAX];
 } grig_cmd_avail_t;
 
 
 #define GRIG_LEVEL_RD (RIG_LEVEL_RFPOWER | RIG_LEVEL_AGC | RIG_LEVEL_SWR | RIG_LEVEL_ALC | \
-		       RIG_LEVEL_STRENGTH | RIG_LEVEL_ATT | RIG_LEVEL_PREAMP | \
+                       RIG_LEVEL_STRENGTH | RIG_LEVEL_ATT | RIG_LEVEL_PREAMP | \
                        RIG_LEVEL_VOX | RIG_LEVEL_AF | RIG_LEVEL_RF | RIG_LEVEL_SQL | \
-		       RIG_LEVEL_IF | RIG_LEVEL_APF | RIG_LEVEL_NR | RIG_LEVEL_PBT_IN | \
-                       RIG_LEVEL_PBT_OUT | RIG_LEVEL_CWPITCH | \
+                       RIG_LEVEL_IF | RIG_LEVEL_APF | RIG_LEVEL_NR | RIG_LEVEL_PBT_IN | \
+                       RIG_LEVEL_PBT_OUT | RIG_LEVEL_CWPITCH |          \
                        RIG_LEVEL_MICGAIN | RIG_LEVEL_KEYSPD | RIG_LEVEL_NOTCHF | \
                        RIG_LEVEL_COMP | RIG_LEVEL_BKINDL | RIG_LEVEL_BALANCE | \
                        RIG_LEVEL_VOXGAIN | RIG_LEVEL_ANTIVOX)
 
 #define GRIG_LEVEL_WR (RIG_LEVEL_RFPOWER | RIG_LEVEL_AGC | RIG_LEVEL_ATT | RIG_LEVEL_PREAMP | \
                        RIG_LEVEL_VOX | RIG_LEVEL_AF | RIG_LEVEL_RF | RIG_LEVEL_SQL | \
-		       RIG_LEVEL_IF | RIG_LEVEL_APF | RIG_LEVEL_NR | RIG_LEVEL_PBT_IN | \
-                       RIG_LEVEL_PBT_OUT | RIG_LEVEL_CWPITCH | \
+                       RIG_LEVEL_IF | RIG_LEVEL_APF | RIG_LEVEL_NR | RIG_LEVEL_PBT_IN | \
+                       RIG_LEVEL_PBT_OUT | RIG_LEVEL_CWPITCH |          \
                        RIG_LEVEL_MICGAIN | RIG_LEVEL_KEYSPD | RIG_LEVEL_NOTCHF | \
                        RIG_LEVEL_COMP | RIG_LEVEL_BKINDL | RIG_LEVEL_BALANCE | \
                        RIG_LEVEL_VOXGAIN | RIG_LEVEL_ANTIVOX)
@@ -219,6 +227,7 @@ int  rig_data_get_preamp_index (int data);
 int  rig_data_get_vfos         (void);
 void rig_data_set_vfos         (int);
 int  rig_data_get_all_modes    (void);
+int  rig_data_get_all_antennas (void);
 
 
 /* FIXME: group functions accoring to functionality */
@@ -236,6 +245,7 @@ void rig_data_set_att     (int);
 void rig_data_set_preamp  (int);
 void rig_data_set_split   (int);
 void rig_data_set_max_rfpwr (float);
+void rig_data_set_antenna   (ant_t);
 
 
 #define rig_data_set_freq1(x) (rig_data_set_freq(1,x))
@@ -265,6 +275,7 @@ shortfreq_t      rig_data_get_xitmax   (void);
 shortfreq_t      rig_data_get_xitstep  (void);
 int              rig_data_get_split    (void);
 float            rig_data_get_max_rfpwr (void);
+ant_t            rig_data_get_antenna   (void);
 
 
 /* has_get functions */
@@ -422,6 +433,11 @@ float rig_data_get_comp     (void);
 void  rig_data_set_comp     (float comp);
 
 
+/* func */
+int   rig_data_has_get_func (setting_t func);
+int   rig_data_has_set_func (setting_t func);
+int   rig_data_get_func     (setting_t func);
+void  rig_data_set_func     (setting_t func, int status);
 
 /* LOCK */
 int  rig_data_has_set_lock (void);
